@@ -23,8 +23,10 @@ class VideoStreamer:
         
       self.__cap = cap
       self.__tasks = []
+      self.__pre_tasks = []
       self.window_name=window_name
       self.waitkey = waitkey
+
       
     def from_webcam(cam_index:int=0,window_name:str="video", waitkey:int=1):
 
@@ -49,7 +51,7 @@ class VideoStreamer:
 
         """
         if not shape is None:
-           self.__tasks.append(lambda img: cv2.resize(img, shape, interpolation=cv2.INTER_AREA))
+           self.__pre_tasks.append(lambda img: cv2.resize(img, shape, interpolation=cv2.INTER_AREA))
            
         def inner(func:Callable[[np.ndarray], None]):
             self.__tasks.append(func)  
@@ -87,6 +89,8 @@ class VideoStreamer:
             ret, frame = self.__cap.read()
             
             if not ret: return
+            for task in self.__pre_tasks:
+                frame = task(frame)
             self.__step(frame)    
         
     
